@@ -324,7 +324,7 @@ class Tado:
         data = self._apiCall(cmd, "DELETE", {}, True)
         return data
 
-    def setZoneOverlay(self, zone, overlayMode, setTemp=None, duration=None, deviceType='HEATING', power="ON", mode=None, fanSpeed=None):
+    def setZoneOverlay(self, zone, overlayMode, setTemp=None, duration=None, deviceType='HEATING', power="ON", mode=None, fanSpeed=None, swing=None):
         """set current overlay for a zone"""
         # pylint: disable=C0103
 
@@ -339,6 +339,8 @@ class Tado:
             post_data["setting"]["temperature"] = {"celsius": setTemp}
             if fanSpeed is not None:
                 post_data["setting"]["fanSpeed"] = fanSpeed
+            if swing is not None:
+                post_data["setting"]["swing"] = swing
 
         if mode is not None:
             post_data["setting"]["mode"] = mode
